@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponse.h 2290M 2007-03-24 20:07:02Z (ローカル) $
+ * $Id: ApacheResponse.h 2290M 2007-03-25 05:00:50Z (ローカル) $
  *****************************************************************************/
 
 #ifndef APACHE_RESPONSE_H
@@ -146,8 +146,14 @@ public:
     };
     static void set_content_type(Handle *r)
     {
-        ap_set_content_type(r, "application/octet-stream");
+        r->content_type = NULL;
+
+        // mod_mime{_magick} に Content-Type の出力を任せる
         ap_run_type_checker(r);
+
+        if (r->content_type == NULL) {
+            ap_set_content_type(r, "application/octet-stream");
+        }
     };
     static void set_content_type(Handle *r, const char *content_type)
     {
