@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CGIRequestReader.h 2193 2006-12-09 01:26:55Z svn $
+ * $Id: CGIRequestReader.h 2297 2006-12-24 03:13:15Z svn $
  *****************************************************************************/
 
 #ifndef CGI_REQUEST_READER_H
@@ -36,7 +36,6 @@
 
 #include "RequestReader.h"
 
-using namespace std;
 
 /**
  * @brief CGI での POST リクエストを読み込むクラス．
@@ -51,7 +50,7 @@ public:
      * @param[in] r リクエスト
      * @param[in] stream 入力ストリーム
      */
-    CGIRequestReader(post_progress_t *progress, void *r, istream *stream=&cin);
+    CGIRequestReader(post_progress_t *progress, void *r, std::istream *stream=&std::cin);
     /**
      * POST リクエストを読み込みます．
      *
@@ -61,7 +60,7 @@ public:
      */
     void read(char *buffer, apr_size_t size, apr_size_t *read_size);
 private:
-    istream *stream_;
+    std::istream *stream_;
 };
 
 #endif
