@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Macro.h 2360 2007-01-07 14:24:25Z svn $
+ * $Id: Macro.h 2374 2007-01-23 13:42:21Z svn $
  *****************************************************************************/
 
 /**
@@ -289,9 +289,9 @@
         cerr << "------------------------------------------------------------"; \
         cerr << endl;                                                   \
         cerr << setw(24) << setiosflags(ios::left) << APR_STRINGIFY(a); \
-        cerr << " = " << (unsigned long long)(a) << endl;                        \
+        cerr << " = " << (ptrdiff_t)(a) << endl;                        \
         cerr << setw(24) << setiosflags(ios::left) << APR_STRINGIFY(b); \
-        cerr << " = " << (unsigned long long)(b) << endl;                        \
+        cerr << " = " << (ptrdiff_t)(b) << endl;                        \
         cerr << "============================================================"; \
         cerr << "\033[0m" << endl;                                      \
         abort();                                                        \
