@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2311 2006-12-24 21:27:56Z svn $
+ * $Id: Auxiliary.cpp 2311M 2007-03-24 20:21:29Z (ローカル) $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -49,7 +49,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2311 2006-12-24 21:27:56Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2311M 2007-03-24 20:21:29Z (ローカル) $");
 
 void init_atomic(apr_pool_t *pool)
 {
@@ -345,10 +345,10 @@ const char *size_str(apr_pool_t *pool, apr_uint64_t size)
                             static_cast<double>(size)/1024, KBYTE_UNIT);
     } else if (size < 1024*1024*1024) {
         return apr_psprintf(pool, "%.1f %s",
-                            static_cast<double>(size/1024)/1024, MBYTE_UNIT);
+                            static_cast<double>(size)/(1024*1024), MBYTE_UNIT);
     } else {
         return apr_psprintf(pool, "%.1f %s",
-                            static_cast<double>(size/(1024*1024))/1024, GBYTE_UNIT);
+                            static_cast<double>(size)/(1024*1024*1024), GBYTE_UNIT);
     }
 }
 
