@@ -22,11 +22,12 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DirectoryCleaner.cpp 2296 2006-12-24 02:58:57Z svn $
+ * $Id: DirectoryCleaner.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
 
+#include "apr_strings.h"
 #include "apr_time.h"
 #include "apr_file_info.h"
 #include "apr_file_io.h"
@@ -36,7 +37,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DirectoryCleaner.cpp 2296 2006-12-24 02:58:57Z svn $");
+SOURCE_INFO_ADD("$Id: DirectoryCleaner.cpp 2388 2007-03-10 11:34:50Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -51,7 +52,11 @@ void DirectoryCleaner::clean_old_files(apr_pool_t *pool,
     char *file_path;
 
     if (apr_dir_open(&dir, dir_path, pool) != APR_SUCCESS) {
-        THROW(MESSAGE_DIR_OPEN_FAILED);
+        throw apr_pstrcat(pool,
+                          MESSAGE_DIR_OPEN_FAILED,
+                          " [", dir_path, "]",
+                          " (" __FILE__ ":" APR_STRINGIFY(__LINE__) ")",
+                          NULL);
     }
 
     current_time = apr_time_now();
