@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.cpp 2291 2006-12-22 14:07:00Z svn $
+ * $Id: TemplateLexer.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: TemplateLexer.cpp 2291 2006-12-22 14:07:00Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateLexer.cpp 2388 2007-03-10 11:34:50Z svn $");
 
 #define AS_TOKEN(pointer)           reinterpret_cast<token_t *>(pointer)
 #define AS_TOKEN_P(pointer)         reinterpret_cast<token_t **>(pointer)
@@ -675,7 +675,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
         dump_level = 0;
     }
 
-    if (!is_exist(pool, tmpl_file_path)) {
+    if (!File::is_exist(pool, tmpl_file_path)) {
         THROW(MESSAGE_TMPL_FILE_NOT_FOUND);
     }
 
