@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 2291 2006-12-22 14:07:00Z svn $
+ * $Id: UploadItemList.cpp 2307 2006-12-24 10:12:09Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2291 2006-12-22 14:07:00Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2307 2006-12-24 10:12:09Z svn $");
 
 #define AS_UHEADER(pointer)     reinterpret_cast<UploadItem::header_t *>(pointer)
 #define AS_UITEM_LIST(pointer)  reinterpret_cast<UploadItemList *>(pointer)
@@ -119,7 +119,7 @@ void UploadItemList::remove(apr_size_t item_id)
                 sizeof(UploadItem::header_t) * (header_list_size - i - 1));
     }
 
-    if (header_list_size == 0) { // 念のため
+    if (total_file_size_ < file_size) {
         THROW(MESSAGE_BUG_FOUND);
     }
 
