@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2384M 2007-03-24 14:29:32Z (ローカル) $
+ * $Id: uploader_handler.cpp 2384M 2007-03-25 05:52:57Z (ローカル) $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -56,7 +56,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2384M 2007-03-24 14:29:32Z (ローカル) $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2384M 2007-03-25 05:52:57Z (ローカル) $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -631,15 +631,15 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
                     const char *arg, bool is_admin_mode=false)
 {
     apr_size_t item_id;
-    const char *file_name;
+    const char *file_path;
     const char *item_id_str;
 
-    file_name = get_word(r->pool, &arg, ARG_SEPARATE_STR[0]);
-    if (strlen(file_name) == 0) {
+    file_path = get_word(r->pool, &arg, ARG_SEPARATE_STR[0]);
+    if (strlen(file_path) == 0) {
         return HTTP_BAD_REQUEST;
     }
 
-    item_id_str = apr_pstrdup(r->pool, file_name);
+    item_id_str = apr_pstrdup(r->pool, file_path);
     item_id = static_cast<apr_size_t>
         (apr_atoi64(get_word(r->pool, &item_id_str, FILE_EXT_SEPARATOR[0])));
 
@@ -649,6 +649,7 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
         apr_file_t *item_file;
         const char *open_mode;
         const char *dispos_encoding;
+        const char *file_name;
 
         if (Response::is_post_method(r)) {
             RequestReader::post_progress_t progress;
@@ -692,9 +693,18 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
         }
 
         try {
+            item_file = config->get_item_manager()
+                ->get_item_file(r->pool, item_id,
+                                Response::Writer::is_sendfile_enabled(r));
+
 #ifdef RESPONSE_TYPE_APACHE
-            r->filename = const_cast<char *>(file_name);
-            r->finfo.filetype = APR_REG;
+            {
+                const char *item_path;
+                apr_file_name_get(&item_path, item_file);
+                r->filename = const_cast<char *>(item_path);
+                r->finfo.filetype = APR_REG;
+                r->finfo.size = uitem->get_file_size();
+            }
             Response::set_content_type(r);
 #else
             Response::set_content_type(r, uitem->get_file_mime());
@@ -715,10 +725,6 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
                 return OK;
             }
 
-            item_file = config->get_item_manager()
-                ->get_item_file(r->pool, item_id,
-                                Response::Writer::is_sendfile_enabled(r));
-
             Response::set_accept_ranges(r);
 
             dispos_encoding = get_dispos_encoding(Response::get_user_agent(r));
