@@ -29,12 +29,12 @@ run make -f GNUmakefile.dist dist-win-sf
     run cd doc
     run make doc-update
     run cp apache.htm apache-win.htm /home/apache/${PACKAGE}/
-);
+)
 
 (
     run rsync -av --max-size=3000000 . ~/cvs/download/${PACKAGE}
     run cd ~/cvs/download/${PACKAGE}
-    run cvs commit -m ""
+    cvs commit -m ""
     run cvs tag release-${VERSION}_`date "+%y%m%d%H%M"`
 )
 
