@@ -95,6 +95,13 @@ sub set_module_env {
     $exp->expect(CMD_TIMEOUT_SEC, '>');
 }
 
+sub exit_cmd {
+    my $exp = shift;
+
+    $exp->send('exit' . "\n");
+    $exp->expect(MAKE_TIMEOUT_SEC, '$');
+}
+
 sub compile_module {
     my $exp = shift;
 
@@ -103,9 +110,6 @@ sub compile_module {
 
     $exp->send('make -f GNUmakefile.win32 2>&1 | nkf -e' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, 'src>');
-
-    $exp->send('exit' . "\n");
-    $exp->expect(MAKE_TIMEOUT_SEC, '$');
 }
 
 sub set_installer_env {
@@ -118,14 +122,18 @@ sub set_installer_env {
     $exp->expect(CMD_TIMEOUT_SEC, '>');
 }
 
+sub compile_utility {
+    my $exp = shift;
+
+    $exp->send('msbuild UploaderConfig/UploaderConfig.csproj /p:Configuration=Release /t:Rebuild 2>&1 | nkf -e' . "\n");
+    $exp->expect(MAKE_TIMEOUT_SEC, 'util>');
+}
+
 sub compile_installer {
     my $exp = shift;
 
     $exp->send('devenv /build release UploaderConfigSetup/UploaderConfigSetup.vdproj 2>&1 | nkf -e' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, 'util>');
-
-    $exp->send('exit' . "\n");
-    $exp->expect(MAKE_TIMEOUT_SEC, '$');
 }
 
 my $user = $ENV{'USER'};
@@ -142,12 +150,16 @@ cd_src_dir($exp);
 set_module_env($exp);
 # ⥸塼Υѥ
 compile_module($exp);
+exit_cmd($exp);
 # ǥ쥯ȥΰư
 cd_util_dir($exp);
 # ĶѿΥå
 set_installer_env($exp);
+# ġΥѥ
+compile_utility($exp);
 # 󥹥ȡΥѥ
 compile_installer($exp);
+exit_cmd($exp);
 
 # Local Variables:
 # mode: cperl
